# -*- coding: utf-8 -*-
#
# sources.connectors.mbs - get information about module builds from MBS
#
# Copyright © 2018, 2019 Red Hat, Inc.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Author:
# Nils Philippsen <nils@redhat.com>

import logging

from .rest import Consumer

log = logging.getLogger(__name__)


class MBSConsumer(Consumer):

    STATE_READY = 5

    pagination = {
        'page_arg': 'page',
        'page_elem': 'meta.page',
        'pages_elem': 'meta.pages',
        'data_elem': 'items',
        'retry_attempts': 5,
    }

    async def get_module_builds(self, **kwargs):
        log.debug(f"get_module_builds(**kwargs={kwargs!r})")
        return await self.get_as_json('module-builds', params=kwargs)

    async def get_module_build(self, sid, **kwargs):
        log.debug(f"get_module_build(sid={sid!r}, **kwargs={kwargs!r})")
        return await self.get_as_json(f'module-builds/{sid}', params=kwargs)
